@@ -1086,7 +1086,9 @@ class Transaction(object):
             'metadata': self.metadata,
             'asset': self.asset,
             'version': self.version,
-            'id': self._id,
+            'app_id': self.app_id,
+            'app_key': self.app_key,
+            'id': self._id
         }
 
     @staticmethod
