@@ -85,6 +85,8 @@ class BigchainDB(object):
                                   .format(', '.join(self.mode_list)))
 
         tx_dict = transaction.tx_dict if transaction.tx_dict else transaction.to_dict()
+        tx_dict["app_id"] = transaction.app_id
+        tx_dict["app_key"] = transaction.app_key
         payload = {
             'method': mode,
             'jsonrpc': '2.0',
